<?php
/*
Plugin Name: Custom HTML Object Processor
Plugin URI: no uri at the moment
Description: Adds a layer between pages and the rendering of the pages
Version: 0.2
Author: Chryzo, hakre
Author URI: http://www.chryzo.net

Copyright 2009  Chryzo  (email : ChrysoInNuke@gmail.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/*
usage:

	[XmlProcessor xml="xml_filepath" xslt="xslt_filepath"]
	
		xml_filepath and xslt_filepath is relative to plugin directory

	[XmlProcessor filepath]
	
		filepath stands for both filenames (.xml and .xsl) without the
		file extension and relative to plugin directory
		
examples:

	[XmlProcessor example]
	
	[XmlProcessor xml="example.xml" xslt="example.xsl"]
	
		Both Examples work the same, they will process example.xml and
		example.xsl located in the plugin directory.	
*/

/**
 * XmlProcessor Shortcode Hook
 * 
 * XML - XSL Processor
 * 
 * @param  array $atts shortcode attributes
 * @return string output of shortcode(processed xml/xslt or error message on failure)
 */
function cpt_process_xml($atts) {
	
	switch (true)
	{
		// one parameter for naming both files
		case isset($atts[0]):
			$xml  = sprintf('%s.xml', $atts[0]);
			$xslt = sprintf('%s.xsl', $atts[0]);			
			break;
			
		// name xml and xslt files with an attribute on it's own.
		case isset($atts["xml"]) && isset($atts["xslt"]):
			$xml  = $atts["xml"];
			$xslt = $atts["xslt"];
			break;
		// set xml and xslt to false if parsing of attributes failed.
		default:
			$xml  = false;
			$xslt = false;
	}
	
	if ($xml !== false)
	{	
		// this will include relative to this file
		$path = dirname(__FILE__);	
		
		$xml  = $path .'/'. $xml;
		$xslt = $path .'/'. $xslt;	
			
		if (file_exists($xml) && file_exists($xslt))
		{
			$xslDoc = new DOMDocument();
			$xslDoc->load($xslt);
					
			$xmlDoc = new DOMDocument();
			$xmlDoc->load($xml);
	
			$proc = new XSLTProcessor();
			$proc->importStylesheet($xslDoc);
			return $proc->transformToXML($xmlDoc);		
		}
	}
	
	return sprintf('<div class="error"><strong>Error processing XML and XSLT. Configuration was: %s</strong></div>', htmlspecialchars(print_r($atts, true)));	
}

if (function_exists("add_shortcode")){
	add_shortcode("XmlProcessor", "cpt_process_xml");
}

?>